@@ -1,5 +1,4 @@
-import converts as cd
-import converter.converts as cda
+import converter.converts as cd
 
 n = 20
 print(cd.c2f(n))
